@@ -56,7 +56,9 @@ sub set {
 }
 
 sub get {
-    $_[0]->{obj}->get($_[1]);
+    my ($self, $key, $trivial) = @_;
+    return undef if $NoTrivial && $trivial;
+    $self->{obj}->get($key);
 }
 
 sub remove {
@@ -73,7 +75,7 @@ sub remove {
 
 sub get_has_user {
     my ($self, $user) = @_;
-    $self->get("hasuser:$user")
+    $self->get("hasuser:$user", 'trivial')
 }
 
 sub set_has_user {
@@ -103,12 +105,12 @@ sub remove_last_res {
 
 sub get_has_model {
     my ($self, $user, $model) = @_;
-    $self->get("hasmodel:$user:$model")
+    $self->get("hasmodel:$user:$model", 'trivial')
 }
 
 sub set_has_model {
     my ($self, $user, $model) = @_;
-    $self->set("hasmodel:$user:$model", 1, 3 * 60, 'trivial');
+    $self->set("hasmodel:$user:$model", 1, 3600, 'trivial');
 }
 
 sub remove_has_model {
@@ -119,12 +121,12 @@ sub remove_has_model {
 sub get_has_view {
     my ($self, $user, $view) = @_;
     #return undef;
-    $self->get("hasview:$user:$view")
+    $self->get("hasview:$user:$view", 'trivial')
 }
 
 sub set_has_view {
     my ($self, $user, $view) = @_;
-    $self->set("hasview:$user:$view", 1, 3 * 60, 'trivial');
+    $self->set("hasview:$user:$view", 1, 3600, 'trivial');
 }
 
 sub remove_has_view {
@@ -132,5 +134,21 @@ sub remove_has_view {
     $self->remove("hasview:$user:$view");
 }
 
+sub get_has_role {
+    my ($self, $user, $role) = @_;
+    #return undef;
+    $self->get("hasrole:$user:$role", 'trivial')
+}
+
+sub set_has_role {
+    my ($self, $user, $role, $login_meth) = @_;
+    $self->set("hasrole:$user:$role", $login_meth, 3600, 'trivial');
+}
+
+sub remove_has_role {
+    my ($self, $user, $role) = @_;
+    $self->remove("hasrole:$user:$role");
+}
+
 1;
 
