@@ -10,8 +10,10 @@ use OpenResty::Cache;
 use OpenResty;
 use OpenResty::Inlined;
 use OpenResty::Config;
+use File::Spec;
 
 our $InitFatal;
+our $StatsLog;
 
 # XXX Excpetion not caputred...when database 'test' not created.
 my %Dispatcher = (
@@ -57,8 +59,17 @@ sub init {
     };
     if ($@) { $InitFatal = $@; }
     #warn "InitFatal: $InitFatal\n";
-    $OpenResty::Backend->set_user('_global');
-    $OpenResty::Backend->do('set lc_messages to "C";');
+    eval {
+        $OpenResty::Backend->set_user('_global');
+        $OpenResty::Backend->do('set lc_messages to "C";');
+    };
+    if ($@) { warn $@ }
+
+    $StatsLog = $OpenResty::Config{'frontend.stats_log_dir'};
+    if ($StatsLog && !-d $StatsLog) {
+        mkdir $StatsLog or
+            die "Can't create directory $StatsLog: $!\n";
+    }
 
     if (my $filtered = $OpenResty::Config{'frontend.filtered'}) {
         #warn "HERE!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!";
@@ -77,6 +88,7 @@ sub process_request {
     my ($class, $cgi, $call_level, $parent_account) = @_;
 
     $call_level ||= 0;
+
     if ($call_level > $ACTION_REC_DEPTH_LIMIT) {
         die "Action calling chain is too deep. (The limit is $ACTION_REC_DEPTH_LIMIT.)\n";
     }
